******************
Getting shelephant
******************

Using conda
===========

The easiest is to use *conda* to install *shelephant*::

    conda install -c conda-forge shelephant

This will install all the necessary runtime dependencies as well.

Using PyPi
==========

Equally easy is to use *pip* to install *shelephant*::

    python -m pip install shelephant

This will install all the necessary runtime dependencies as well.

Manual install
==============

Installing GooseSLUM proceeds easily with ``pip``:

.. code-block:: bash

    cd /path/to/shelephant
    python -m pip install .

This should install all the necessary runtime dependencies as well.
